Welcome to PyNOT : Response

#### Start-up

First, load a 1D-extracted spectrum of a spectroscopic standard star by pressing the Load button or using the keyboard shortcut 'cmd + O' (if on Mac) otherwise use 'control + O'.
If the star name is not found in the FITS header, then you must manually select the star name in the drop-down menu on the right (if the star you observed is not in the list, you have to use another spectrum or install the corresponding flux table for the star, see online documentation).
Once a star has been loaded, a range of blue points show up in the plotting area on top of the spectrum. These points indicate the regions where the standard star has flux measurements defined.

#### Fitting the Response Function

Interpolate the instrumental response function shown as blue points by pressing Fit Response. Outlying points (affected by emission or absorption) should be removed by clicking on them. This turns a given blue point into a red cross which will not be included in the fit.
If you want to include a point again, simply click on the red cross to re-activate it (changes back to blue point).
You can change the spline order and the smoothing value in order to obtain a better fit. A smoothing value of 0 forces the spline interpolation to go through all the red points.
When you are happy with a solution, save the response function by clicking Done.